@@ -208,7 +208,7 @@ class BasePythonProject(BaseProject[SpecT]):
             timeout=timeout,
             deadline=deadline,
             env=environment,
-            append_path=self.venv_path / "bin",
+            append_path=self.venv_bin,
             rc=rc,
             quiet=quiet,
             **kwargs,
